from distutils.core import setup

setup(name='kinetic_auto_test',
      version='0.0',
      description='testing package for kinetic',
      author='Srikanth Malla',
      author_email='srikanth@kinetic.auto',
      url='http://www.kinetic.auto//',
      packages=['kinetic_auto_test'],
     )
